﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.IO;
using System.Linq;
using Windows.Devices.Sensors;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Core;
using Windows.UI.Input;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace MetroSteeringWheel
{
    public class Rotation : INotifyPropertyChanged
    {
        Double angle;
        public double Angle { 
            get 
            {
                return angle;
            }
            set
            {
                
                angle = value;
                NotifyPropertyChanged("Angle");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }

    }
  
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    /// 
    public sealed partial class BlankPage : Page
    {
        Rotation wheelRotation;
        Inclinometer inclinoMeter;
        InclinometerReading reading;
        float initialYaw = 0.0f;
        LightSensor als;
        bool IsClosing=false;
        public BlankPage()
        {
            this.InitializeComponent();

            wheelRotation = new Rotation();
            wheelRotation.Angle = 0.0f;
            this.DataContext = wheelRotation;
            inclinoMeter=Inclinometer.GetDefault();
            
            if (inclinoMeter != null)
            {
                inclinoMeter.ReportInterval = inclinoMeter.MinimumReportInterval;
                
                inclinoMeter.ReadingChanged += inclinoMeter_ReadingChanged;
                reading = inclinoMeter.GetCurrentReading();
                initialYaw = reading.YawDegrees;
            }
            als= LightSensor.GetDefault();
            if (als != null)
            {
                als.ReadingChanged += als_ReadingChanged;

            }
            
        }

        void als_ReadingChanged(LightSensor sender, LightSensorReadingChangedEventArgs args)
        {
            if (IsClosing) return;
            UpdateLighting(sender, args);
        }

        private void UpdateLighting(LightSensor sender, LightSensorReadingChangedEventArgs args)
        {
            this.Dispatcher.RunAsync(CoreDispatcherPriority.Normal,
                new DispatchedHandler(() =>
                {
                    if (tglOffAuto.IsChecked == true)
                    {

                        if (args.Reading.IlluminanceInLux <= 100)
                        {
                            interiorDark.Opacity = 1.0f;
                        }
                        else
                        {
                            interiorDark.Opacity = 0.0f;
                        }
                    }
                }));
        }

        void inclinoMeter_ReadingChanged(Inclinometer sender, 
            InclinometerReadingChangedEventArgs args)
        {

            if (IsClosing) return;
            UpdateWheelPosition(args);
                
            
        }

        private void UpdateWheelPosition(InclinometerReadingChangedEventArgs args)
        {

            this.Dispatcher.RunAsync(CoreDispatcherPriority.Normal,
                new DispatchedHandler(() =>
                {

                    wheelRotation.Angle = initialYaw - args.Reading.YawDegrees;


                }));
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
        }

        private void cmdExit_Click(object sender, RoutedEventArgs e)
        {
            IsClosing=true;
            if (als != null)
            {
                als.ReadingChanged -= als_ReadingChanged;
            }
            if (inclinoMeter != null)
            {
                inclinoMeter.ReadingChanged += inclinoMeter_ReadingChanged;
            }
            Application.Current.Exit();
            //Window.Current.Close();
        }

        private void wheel_PointerPressed(object sender, Windows.UI.Xaml.Input.PointerRoutedEventArgs e)
        {
            PointerPoint p = e.GetCurrentPoint(this.wheel);
              if ((p.Position.X > 300 && p.Position.X < 400) && (p.Position.Y > 300 && p.Position.Y < 450))
                {
                    honk.IsMuted = false;
                    honk.Play();    
                }                        
        }

        private void tglOffAuto_Click(object sender, RoutedEventArgs e)
        {
            tglOffAuto.Content = tglOffAuto.IsChecked == true ? "Auto" : "Off";
        }


      

      

       
    }
}
